@@ -1,4 +1,4 @@
-from typing import Dict, Optional
+from typing import Dict
 from pypicgo.core.base.file import UploadFile
 
 
